## Run an example
Navigate to the `/examples` repository
```bash
cd examples
```

Create a virtual environment
```bash
python3 -m venv .venv
```

Activate the virtual environment
```bash
source .venv/bin/activate
```


Install the requirements
```bash
python3 -m pip install -r requirements.txt
```

Run an example
```bash
python3 <EXAMPLE-FILE.py>
```